/* 
Module 7 Querying Tables in a Data Warehouse Demonstration SQL 

This demo uses the AdventureWorksDW2012 database which is the data warehouse
that corresponds to the AdventureWorks2012 operational database.

The data warehouse used is still a relational database but it is designed as a star schema
with fact tables and dimension tables.  This star schema structure makes it easier to join 
tables and get information.

You should create a database diagram that contains the following tables: dimCustomer, dimGeography,dimProduct,
dimProductSubCategory, dimProductCategory, factInternetSales
*/

--First let's investigate some of the data in the data warehouse

--List all AdventureWorks customers
--Note that we use the Customer dimension table
--Note that finding the name of a customer is much easier than in the
--AdventureWorks2012 operational database

SELECT * FROM dimCustomer

SELECT CONCAT(FirstName,N' ' + + MiddleName,N' ' + LastName,N' ') AS FullName
FROM [dbo].[DimCustomer]

----------------------------------------------------------------------------------
--List all AdventureWorks customers whose Yearly Income is greater than $50,000 and
-- who own their own homes

SELECT CustomerKey, LastName, FirstName, YearlyIncome, HouseOwnerFlag
FROM dimCustomer
WHERE YearlyIncome > 50000 and HouseOwnerFlag = '1'
ORDER BY YearlyIncome desc

--------------------------------------------------
--List all AdventureWorks customers who live outside the US
--investigate the geography information available
SELECT * FROM dimGeography

--now do the query

SELECT CustomerKey, LastName, FirstName, EnglishCountryRegionName
FROM dimCustomer AS  C 
INNER JOIN DimGeography AS G
    ON C.GeographyKey=G.GeographyKey
WHERE CountryRegionCode <> 'US'
ORDER BY EnglishCountryRegionName,LastName,FirstName

-----------------------------------------------------
-- List all products purchased over the Internet by customer Valerie Zhou - customer key 17828
--investigate the Product information available

SELECT * FROM dimProduct

--now do the query
--Note that each fact table row has a customer and a product associated

SELECT C.CustomerKey, C.LastName, C.FirstName, P.EnglishProductName,
F.OrderQuantity, F.UnitPrice, F.SalesAmount
FROM dimCustomer AS C
INNER JOIN factInternetSales AS F 
    ON C.CustomerKey = F.CustomerKey
INNER JOIN DimProduct AS P 
    ON P.ProductKey=f.ProductKey
WHERE C.CustomerKey =17828

-----------------------------------------------------------
-- We would like to list customers who have purchased Bikes
-- over the Internet

--Investigate the dimProductCategory table
SELECT * FROM dimProductCategory

--Note that Bikes is a Product Category

--Note that there is no Product Category key in the fact table
-- but there is a Product key

--Note that in the dimProduct table there is no Product Category key
-- but there is a Product SubCategory key

--Now construct the query

SELECT DISTINCT LastName, FirstName, PC.EnglishProductCategoryName 
FROM dimCustomer AS C
INNER JOIN factInternetSales AS F 
    ON C.CustomerKey=F.CustomerKey
INNER JOIN dimProduct AS P 
    ON P.ProductKey=F.ProductKey
INNER JOIN dimProductSubcategory AS PS 
    ON PS.ProductSubcategoryKey=P.ProductSubcategoryKey
INNER JOIN DimProductCategory AS PC 
    ON PC.ProductCategoryKey = PS.ProductCategoryKey
WHERE PC.ProductCategoryKey = 1


